### This is a mirror package!

It is recommended to install [`sponsorblock.py`](https://pypi.org/project/sponsorblock.py/) instead.

PYPI: <https://pypi.org/project/sponsorblock.py/>\
GitHub: <https://github.com/wasi-master/sponsorblock.py/tree/main>\
Documentation: <https://sponsorblockpy.readthedocs.io/en/latest/>
